==> openftd-0.98.6.tar.bz2: openftd-0.98.6/ftd_core/src/ftd_xml_parse.c <==
/* ====================================================================
 * FTD4Linux Software License, Version 1.0
 *
 * Copyright (c) 2000-2004 The FTD4Linux Development Team.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        FTD4Linux Development Team (http://www.ftd4linux.2y.net/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "FTD" and "FTD4Linux" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact alguno@ftd4linux.2y.net.
 *
 * 5. Products derived from this software may not be called "FTD4Linux",
 *    nor may "FTD4Linux" appear in their name, without prior written
 *    permission of the FTD4Linux Development Team.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE FTD4LINUX DEVELOPMENT TEAM OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <libxml/tree.h>
#include "ftd4linux.h"
#include "ftd_app_core.h"
#include "ftd_groups.h"

/**
 * Geeft een int terug uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een int bevat.
 *
 * @return  De gelezen int.
 */
int
ftd_xml_parse_int(xmlDocPtr doc, xmlNodePtr cur)
{
    char *ret;
    int   retInt = 0;

    ret = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
    if (ret) {
        retInt = atoi(ret);
        xmlFree(ret);
    }
    return retInt;
}

/**
 * Geeft een string terug uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een string bevat.
 *
 * @return  Een nieuwe string met de gelezen inhoud.
 */
FtdString *
ftd_xml_parse_string(xmlDocPtr doc, xmlNodePtr cur)
{
    char *ret;
    FtdString *string = NULL;

    ret = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
    if (ret) {
        string = ftd_string_new(ret);
        xmlFree(ret);
    }
    return string;
}

/**
 * Geeft de int-waarde van een attribuut uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een attribuut bevat.
 * @arg     attrName    De naam van het attribuut.
 *
 * @return  De int-waarde van het attribuut attrName in het element cur in het document doc.
 */
int
ftd_xml_parse_int_attr(xmlDocPtr doc, xmlNodePtr cur, char *attrName)
{
    char *ret;
    int retInt = 0;

    g_assert(attrName);

    ret = xmlGetProp(cur, attrName);
    if (ret) {
        retInt = atoi(ret);
        xmlFree(ret);
    }
    return retInt;
}

==> openftd-1.1.0.tar.bz2: openftd-1.1.0/ftd_core/src/ftd_xml_parse.c <==
/* ====================================================================
 * FTD4Linux Software License, Version 1.0
 *
 * Copyright (c) 2000-2004 The FTD4Linux Development Team.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        FTD4Linux Development Team (http://www.ftd4linux.2y.net/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "FTD" and "FTD4Linux" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact alguno@ftd4linux.2y.net.
 *
 * 5. Products derived from this software may not be called "FTD4Linux",
 *    nor may "FTD4Linux" appear in their name, without prior written
 *    permission of the FTD4Linux Development Team.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE FTD4LINUX DEVELOPMENT TEAM OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <libxml/tree.h>
#include "openftd.h"
#include "ftd_app_core.h"
#include "ftd_groups.h"

/**
 * Geeft een int terug uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een int bevat.
 *
 * @return  De gelezen int.
 */
int
ftd_xml_parse_int(xmlDocPtr doc, xmlNodePtr cur)
{
    char *ret;
    int   retInt = 0;

    ret = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
    if (ret) {
        retInt = atoi(ret);
        xmlFree(ret);
    }
    return retInt;
}

/**
 * Geeft een GString terug uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een string bevat.
 *
 * @return  Een nieuwe GString met de gelezen inhoud.
 */
FtdString *
ftd_xml_parse_gstring(xmlDocPtr doc, xmlNodePtr cur)
{
    char *ret;
    FtdString *string = NULL;

    ret = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
    if (ret) {
        string = ftd_string_new(ret);
        xmlFree(ret);
    }
    return string;
}

/**
 * Bewaart een string uit een XML boom in een opgegeven pointer.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een string bevat.

 *
 * @return  Een nieuwe string met de gelezen inhoud.
 */
void
ftd_xml_parse_string2(xmlDocPtr doc, xmlNodePtr cur, char *ptr, int length)
{
    char *ret;

    ret = xmlNodeListGetString(doc, cur->xmlChildrenNode, 1);
    if (ret) {
        snprintf(ptr, length, "%s", ret);
        xmlFree(ret);
    } else {
        ptr[0] = '\0';
    }
}

/**
 * Geeft de int-waarde van een attribuut uit een XML boom.
 *
 * @arg     doc         Het XML document.
 * @arg     cur         Een pointer naar het element in het XML document dat een attribuut bevat.
 * @arg     attrName    De naam van het attribuut.
 *
 * @return  De int-waarde van het attribuut attrName in het element cur in het document doc.
 */
int
ftd_xml_parse_int_attr(xmlDocPtr doc, xmlNodePtr cur, char *attrName)
{
    char *ret;
    int retInt = 0;

    g_assert(attrName);

    ret = xmlGetProp(cur, attrName);
    if (ret) {
        retInt = atoi(ret);
        xmlFree(ret);
    }
    return retInt;
}
